@@ -2,7 +2,7 @@ package App::Sys::Info;
 use strict;
 use warnings;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 use constant CP_UTF8      => 65_001;
 use constant LAST_ELEMENT =>     -1;
@@ -37,8 +37,20 @@ sub _chcp {
 sub new {
     my $class  = shift;
     my $i      = Sys::Info->new;
+    my $loc    = do {
+        my $rv;
+        eval {
+            $rv = setlocale( LC_CTYPE );
+            1;
+        } or do {
+            my $error = $@ || 'Unknown error';
+            warn "Unable to collect the locale information: $error";
+            $rv = '';
+        };
+        $rv;
+    };
     my $self   = {
-        LOCALE => setlocale( LC_CTYPE ),
+        LOCALE => $loc,
         NA     => 'N/A',
         info   => $i,
         os     => $i->os,
@@ -349,8 +361,8 @@ Run C<psysinfo> from the command line.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.23> of C<App::Sys::Info>
-released on C<11 May 2013>.
+This document describes version C<0.24> of C<App::Sys::Info>
+released on C<21 January 2015>.
 
 The output is similar to I<systeminfo> windows command.
 
@@ -382,11 +394,11 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2010 - 2013 Burak Gursoy. All rights reserved.
+Copyright 2010 - 2015 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.12.4 or,
+it under the same terms as Perl itself, either Perl version 5.16.2 or,
 at your option, any later version of Perl 5 you may have available.
 =cut
